Index: chrome/browser/ui/views/tabs/tab_controller.h |
diff --git a/chrome/browser/ui/views/tabs/tab_controller.h b/chrome/browser/ui/views/tabs/tab_controller.h |
index 5e26ecf27c9bebda0e5558027e219f0fe2e160a9..3e8807be7b45ea6864b425b352a0ef765a75122f 100644 |
--- a/chrome/browser/ui/views/tabs/tab_controller.h |
+++ b/chrome/browser/ui/views/tabs/tab_controller.h |
@@ -29,9 +29,9 @@ class TabController { |
// Returns true if multiple selection is supported. |
virtual bool SupportsMultipleSelection() = 0; |
- // Returns true if we should force the close button of the inactive tab |
- // |tab| to be hidden. |
- virtual bool ShouldHideCloseButtonForInactiveTab(const Tab* tab) = 0; |
+ // Returns true if we should force the close buttons of the inactive tabs |
+ // to be hidden. |
+ virtual bool ShouldHideCloseButtonForInactiveTabs() = 0; |
// Selects the tab. |
virtual void SelectTab(Tab* tab) = 0; |